      subroutine pfile_info(inunit)
      
C     Reads in particle parameter file header information
      
      implicit none
      integer, intent(in) :: inunit

      include '../include/allprogs.inc'
      include '../include/info.inc'

      include '../include/pifhead.inc'
      type (pifhead_t) maphead, imghead
      common /pifhead/   maphead, imghead
      
      integer temp_units, num_secs, total_views, ios, i, loc
      character(len=filename_len) :: fname
      character(len=11)  :: subname
      data subname /'pfile_info'/

      nfiles      = 0           ! count the number of parameter files
      total_views = 0           ! count the number of images to search
      box_out     = -1          ! initialize maximum particle diameter
      pixsiz_out  =  100000.0   ! initialize pixsiz_out
      pixsiz_max  = -100000.0   ! initialize pixsiz_max

      do i = 1, 10000

C     Read parameter file name from standard input and check status  
C     ios < 0 : end of file reached, break out of loop
C     ios > 0 : error reading file, terminate program
         read (inunit, '(A)', iostat=ios) fname
         if(ios < 0) then
            exit
         else if (ios > 0) then
            call error_stop(progname,subname,
     +           '* error reading parameter filename: exit program')
         endif
             
C     Get rid of leading spaces in parameter file name
         fname = trim(adjustl(fname))
            
C     Go to next iteration if blank line encountered
         if (fname(1:1) == ' ') cycle
         if (fname(1:1) == '#') cycle

C     Increment the file number
         nfiles = nfiles + 1

C     Make sure that maximum number of parameter files not exceeded
         if(nfiles > 999) then
            call error_stop(progname,subname,
     +           '* more than 999 parameter files: exit program')
         endif
         
C     Open particle parameter file
         open(unit=3, file=fname, iostat=ios)
         if(ios .ne. 0) then
            call error_stop(progname,subname,
     $           '* error opening parameter file: exit program')
         endif

C     Get image file name from first line of parameter file
         read(3,'(A)', iostat=ios) img_fnames(nfiles)
         if(ios .ne. 0) then
            call error_stop(progname,subname,
     $           '* error reading image filename: exit program')
         endif

C     The image file name may be specified with or without full path
C     information. For example /dir/subdir/image.pif or image.pif. To
C     allow greater flexibility, we first test to see if the image file
C     can be opened using the full path. If this fails, we then trim off
C     the path and try to open the file again.

C     Get rid of leading whitspace
         img_fnames(nfiles) = adjustl(img_fnames(nfiles))

C     Open the image file as specified in parameter file
         open(unit=25, file=img_fnames(nfiles), status='old',
     $        form='unformatted', iostat=ios)
         close(25)

C     Test result of open. If failed, then try without path info
         if(ios == 0) then
            write(*,*) 'image file OK: ', trim(img_fnames(nfiles))
         else
            loc = index(img_fnames(nfiles), '/', .true.)
            img_fnames(nfiles) = img_fnames(nfiles)(loc+1:filename_len)
            open(unit=25, file=img_fnames(nfiles), status='old',
     $           form='unformatted', iostat=ios)
            close(25)
            if(ios == 0) then
               write(*,*) 'image file path info removed: ',
     $              trim(img_fnames(nfiles))
            else
               write(*,*) 'Unable to open image file: ', 
     $              img_fnames(nfiles)
               call error_stop(progname,subname,
     $              '* Unable to open image file')
            endif
         endif

C     Get pixel size, units, etc. from second line of parameter file
         read(3, *, iostat=ios) pixsizs(nfiles), temp_units,
     $        volts(nfiles), ampfacs(nfiles), delf_majs(nfiles),
     $        delf_mins(nfiles), ang_majs(nfiles), cs_coeffs(nfiles)
         if(ios .ne. 0) then
            call error_stop(progname,subname,
     $           '* error reading parameter file header: exit program')
         endif

         close(unit=3)

C     Make sure that value of units is valid
         if(temp_units < 1 .or. temp_units > 2) then
            call error_stop(progname,subname,
     +           '* value for unit should be 1 or 2 in param file *')
         endif

c     For purposes of calculations within this program convert all pixel
c     sizes to same units as "units"
         if(temp_units .ne. units) then
            if(temp_units == 1) then
               pixsizs(nfiles) = pixsizs(nfiles) / 10.0 ! convert to nm
            else
               pixsizs(nfiles) = pixsizs(nfiles) * 10.0 ! convert to angstroms
            endif
         endif
         pixsiz_out           = min(pixsiz_out,pixsizs(nfiles))
         pixsiz_max           = max(pixsiz_max,pixsizs(nfiles))
         param_fnames(nfiles) = fname
         
c     Open image file and check size of each particle to determine
c     largest value of box_out. Count particles in parameter file and
c     find one with highest value

         imghead%lunum = pix_file_unit
         call pif_open (img_fnames(nfiles), imghead%lunum, 'r')
         call pif_read_gh (imghead)
         npix_col      = imghead%numcols
         npix_row      = imghead%numrows
         num_secs      = imghead%numsecs
         pixhd_endian  = imghead%endianness
         pixhd_htyp    = imghead%htype
         pixhd_mode    = imghead%mode
         
         if (npix_col .ne. npix_row ) then
            call error_stop(progname,subname,
     +           ' * param file npix_col != npix_row: exit program *')
         endif
         
         nbox(nfiles) = npix_col
         box_out      = max(box_out, npix_col)
         
         if(imghead%nimg == 0) then
            call error_stop(progname,subname,
     $           ' * image file contains no data: exit program *')
         endif
         
         nids(nfiles) = imghead%nimg
         total_views  = total_views + imghead%nimg
         
         call pif_close(pix_file_unit)
         
         write(*,*) 'file #',nfiles,'orient file: ',
     $        trim(adjustl(param_fnames(nfiles)))
         write(*,*) 'file #',nfiles,'image  file: ',
     $        trim(adjustl(img_fnames(nfiles)))
         write(*,*) 'views = ',  imghead%nimg, num_secs
         write(*,*) 'numcols = ', npix_col, 'numrows = ', npix_row

         if(nfiles == 1) then
            min_nids = imghead%nimg
         else
            min_nids = min(min_nids, imghead%nimg)
         endif
         
      enddo
      
      write(*,'(i5,a,i6,a)') nfiles, ' parameter files and total of',
     $     total_views , ' images for computation.'
      

      npix_row = box_out
      npix_col = box_out
      
      return
      end subroutine pfile_info
      
